# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from bareun import custom_dict_pb2 as bareun_dot_custom__dict__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class CustomDictionaryServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetCustomDictionaryList = channel.unary_unary(
                '/bareun.CustomDictionaryService/GetCustomDictionaryList',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=bareun_dot_custom__dict__pb2.GetCustomDictionaryListResponse.FromString,
                )
        self.GetCustomDictionary = channel.unary_unary(
                '/bareun.CustomDictionaryService/GetCustomDictionary',
                request_serializer=bareun_dot_custom__dict__pb2.GetCustomDictionaryRequest.SerializeToString,
                response_deserializer=bareun_dot_custom__dict__pb2.GetCustomDictionaryResponse.FromString,
                )
        self.UpdateCustomDictionary = channel.unary_unary(
                '/bareun.CustomDictionaryService/UpdateCustomDictionary',
                request_serializer=bareun_dot_custom__dict__pb2.UpdateCustomDictionaryRequest.SerializeToString,
                response_deserializer=bareun_dot_custom__dict__pb2.UpdateCustomDictionaryResponse.FromString,
                )
        self.RemoveCustomDictionaries = channel.unary_unary(
                '/bareun.CustomDictionaryService/RemoveCustomDictionaries',
                request_serializer=bareun_dot_custom__dict__pb2.RemoveCustomDictionariesRequest.SerializeToString,
                response_deserializer=bareun_dot_custom__dict__pb2.RemoveCustomDictionariesResponse.FromString,
                )
        self.CheckConflict = channel.unary_unary(
                '/bareun.CustomDictionaryService/CheckConflict',
                request_serializer=bareun_dot_custom__dict__pb2.CheckConflictRequest.SerializeToString,
                response_deserializer=bareun_dot_custom__dict__pb2.CheckConflictResponse.FromString,
                )


class CustomDictionaryServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetCustomDictionaryList(self, request, context):
        """전체 목록을 다 가져오기
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCustomDictionary(self, request, context):
        """현재 저장되어 있는 사전 하나만 가져온다.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateCustomDictionary(self, request, context):
        """전체를 모두 다 바꿔치기하는 경우
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveCustomDictionaries(self, request, context):
        """여러 개를 한꺼번에 지운다.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CheckConflict(self, request, context):
        """사용사 사전 사이의 충돌을 점검한다.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CustomDictionaryServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetCustomDictionaryList': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCustomDictionaryList,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=bareun_dot_custom__dict__pb2.GetCustomDictionaryListResponse.SerializeToString,
            ),
            'GetCustomDictionary': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCustomDictionary,
                    request_deserializer=bareun_dot_custom__dict__pb2.GetCustomDictionaryRequest.FromString,
                    response_serializer=bareun_dot_custom__dict__pb2.GetCustomDictionaryResponse.SerializeToString,
            ),
            'UpdateCustomDictionary': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateCustomDictionary,
                    request_deserializer=bareun_dot_custom__dict__pb2.UpdateCustomDictionaryRequest.FromString,
                    response_serializer=bareun_dot_custom__dict__pb2.UpdateCustomDictionaryResponse.SerializeToString,
            ),
            'RemoveCustomDictionaries': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveCustomDictionaries,
                    request_deserializer=bareun_dot_custom__dict__pb2.RemoveCustomDictionariesRequest.FromString,
                    response_serializer=bareun_dot_custom__dict__pb2.RemoveCustomDictionariesResponse.SerializeToString,
            ),
            'CheckConflict': grpc.unary_unary_rpc_method_handler(
                    servicer.CheckConflict,
                    request_deserializer=bareun_dot_custom__dict__pb2.CheckConflictRequest.FromString,
                    response_serializer=bareun_dot_custom__dict__pb2.CheckConflictResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'bareun.CustomDictionaryService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class CustomDictionaryService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetCustomDictionaryList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bareun.CustomDictionaryService/GetCustomDictionaryList',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            bareun_dot_custom__dict__pb2.GetCustomDictionaryListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCustomDictionary(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bareun.CustomDictionaryService/GetCustomDictionary',
            bareun_dot_custom__dict__pb2.GetCustomDictionaryRequest.SerializeToString,
            bareun_dot_custom__dict__pb2.GetCustomDictionaryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateCustomDictionary(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bareun.CustomDictionaryService/UpdateCustomDictionary',
            bareun_dot_custom__dict__pb2.UpdateCustomDictionaryRequest.SerializeToString,
            bareun_dot_custom__dict__pb2.UpdateCustomDictionaryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveCustomDictionaries(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bareun.CustomDictionaryService/RemoveCustomDictionaries',
            bareun_dot_custom__dict__pb2.RemoveCustomDictionariesRequest.SerializeToString,
            bareun_dot_custom__dict__pb2.RemoveCustomDictionariesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CheckConflict(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bareun.CustomDictionaryService/CheckConflict',
            bareun_dot_custom__dict__pb2.CheckConflictRequest.SerializeToString,
            bareun_dot_custom__dict__pb2.CheckConflictResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
