"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2019-present BAIKAL AI Inc."""
import abc
import bareun.language_service_pb2
import grpc

class LanguageServiceStub:
    """한국어에 대한 분석 서비스를 제공하는 서비스."""

    def __init__(self, channel: grpc.Channel) -> None: ...
    AnalyzeSyntax: grpc.UnaryUnaryMultiCallable[
        bareun.language_service_pb2.AnalyzeSyntaxRequest,
        bareun.language_service_pb2.AnalyzeSyntaxResponse,
    ]
    """텍스트의 형태를 분석하고, 문장 경계를 파악하여 토큰 단위로 잘라낸다."""
    AnalyzeSyntaxList: grpc.UnaryUnaryMultiCallable[
        bareun.language_service_pb2.AnalyzeSyntaxListRequest,
        bareun.language_service_pb2.AnalyzeSyntaxListResponse,
    ]
    """복수의 문장을 대상으로 텍스트의 형태를 분석하고, 토큰 단위로 잘라낸다.
    복수의 문장에 대한 순서를 그대로 반환하고 문장을 분할하지 않는다.
    """
    Tokenize: grpc.UnaryUnaryMultiCallable[
        bareun.language_service_pb2.TokenizeRequest,
        bareun.language_service_pb2.TokenizeResponse,
    ]
    """한국어의 특성에 따라서 텍스트를 분절 단뤼로 구분해 낸다."""

class LanguageServiceServicer(metaclass=abc.ABCMeta):
    """한국어에 대한 분석 서비스를 제공하는 서비스."""

    @abc.abstractmethod
    def AnalyzeSyntax(
        self,
        request: bareun.language_service_pb2.AnalyzeSyntaxRequest,
        context: grpc.ServicerContext,
    ) -> bareun.language_service_pb2.AnalyzeSyntaxResponse:
        """텍스트의 형태를 분석하고, 문장 경계를 파악하여 토큰 단위로 잘라낸다."""
    @abc.abstractmethod
    def AnalyzeSyntaxList(
        self,
        request: bareun.language_service_pb2.AnalyzeSyntaxListRequest,
        context: grpc.ServicerContext,
    ) -> bareun.language_service_pb2.AnalyzeSyntaxListResponse:
        """복수의 문장을 대상으로 텍스트의 형태를 분석하고, 토큰 단위로 잘라낸다.
        복수의 문장에 대한 순서를 그대로 반환하고 문장을 분할하지 않는다.
        """
    @abc.abstractmethod
    def Tokenize(
        self,
        request: bareun.language_service_pb2.TokenizeRequest,
        context: grpc.ServicerContext,
    ) -> bareun.language_service_pb2.TokenizeResponse:
        """한국어의 특성에 따라서 텍스트를 분절 단뤼로 구분해 낸다."""

def add_LanguageServiceServicer_to_server(servicer: LanguageServiceServicer, server: grpc.Server) -> None: ...
