"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2019-present BAIKAL AI Inc."""
import abc
import bareun.custom_dict_pb2
import google.protobuf.empty_pb2
import grpc

class CustomDictionaryServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    GetCustomDictionaryList: grpc.UnaryUnaryMultiCallable[
        google.protobuf.empty_pb2.Empty,
        bareun.custom_dict_pb2.GetCustomDictionaryListResponse,
    ]
    """전체 목록을 다 가져오기"""
    GetCustomDictionary: grpc.UnaryUnaryMultiCallable[
        bareun.custom_dict_pb2.GetCustomDictionaryRequest,
        bareun.custom_dict_pb2.GetCustomDictionaryResponse,
    ]
    """현재 저장되어 있는 사전 하나만 가져온다."""
    UpdateCustomDictionary: grpc.UnaryUnaryMultiCallable[
        bareun.custom_dict_pb2.UpdateCustomDictionaryRequest,
        bareun.custom_dict_pb2.UpdateCustomDictionaryResponse,
    ]
    """전체를 모두 다 바꿔치기하는 경우"""
    RemoveCustomDictionaries: grpc.UnaryUnaryMultiCallable[
        bareun.custom_dict_pb2.RemoveCustomDictionariesRequest,
        bareun.custom_dict_pb2.RemoveCustomDictionariesResponse,
    ]
    """여러 개를 한꺼번에 지운다."""
    CheckConflict: grpc.UnaryUnaryMultiCallable[
        bareun.custom_dict_pb2.CheckConflictRequest,
        bareun.custom_dict_pb2.CheckConflictResponse,
    ]
    """사용사 사전 사이의 충돌을 점검한다."""

class CustomDictionaryServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetCustomDictionaryList(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: grpc.ServicerContext,
    ) -> bareun.custom_dict_pb2.GetCustomDictionaryListResponse:
        """전체 목록을 다 가져오기"""
    @abc.abstractmethod
    def GetCustomDictionary(
        self,
        request: bareun.custom_dict_pb2.GetCustomDictionaryRequest,
        context: grpc.ServicerContext,
    ) -> bareun.custom_dict_pb2.GetCustomDictionaryResponse:
        """현재 저장되어 있는 사전 하나만 가져온다."""
    @abc.abstractmethod
    def UpdateCustomDictionary(
        self,
        request: bareun.custom_dict_pb2.UpdateCustomDictionaryRequest,
        context: grpc.ServicerContext,
    ) -> bareun.custom_dict_pb2.UpdateCustomDictionaryResponse:
        """전체를 모두 다 바꿔치기하는 경우"""
    @abc.abstractmethod
    def RemoveCustomDictionaries(
        self,
        request: bareun.custom_dict_pb2.RemoveCustomDictionariesRequest,
        context: grpc.ServicerContext,
    ) -> bareun.custom_dict_pb2.RemoveCustomDictionariesResponse:
        """여러 개를 한꺼번에 지운다."""
    @abc.abstractmethod
    def CheckConflict(
        self,
        request: bareun.custom_dict_pb2.CheckConflictRequest,
        context: grpc.ServicerContext,
    ) -> bareun.custom_dict_pb2.CheckConflictResponse:
        """사용사 사전 사이의 충돌을 점검한다."""

def add_CustomDictionaryServiceServicer_to_server(servicer: CustomDictionaryServiceServicer, server: grpc.Server) -> None: ...
