# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bareun/lang_common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x62\x61reun/lang_common.proto\x12\x06\x62\x61reun\"A\n\x08TextSpan\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12\x14\n\x0c\x62\x65gin_offset\x18\x02 \x01(\x05\x12\x0e\n\x06length\x18\x03 \x01(\x05\"-\n\x08\x44ocument\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12\x10\n\x08language\x18\x04 \x01(\t*8\n\x0c\x45ncodingType\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04UTF8\x10\x01\x12\t\n\x05UTF16\x10\x02\x12\t\n\x05UTF32\x10\x03\x42=\n\x10\x61i.bareun.protosB\x0fLangCommonProtoP\x01Z\x16\x62\x61reun.ai/proto/bareunb\x06proto3')

_ENCODINGTYPE = DESCRIPTOR.enum_types_by_name['EncodingType']
EncodingType = enum_type_wrapper.EnumTypeWrapper(_ENCODINGTYPE)
NONE = 0
UTF8 = 1
UTF16 = 2
UTF32 = 3


_TEXTSPAN = DESCRIPTOR.message_types_by_name['TextSpan']
_DOCUMENT = DESCRIPTOR.message_types_by_name['Document']
TextSpan = _reflection.GeneratedProtocolMessageType('TextSpan', (_message.Message,), {
  'DESCRIPTOR' : _TEXTSPAN,
  '__module__' : 'bareun.lang_common_pb2'
  # @@protoc_insertion_point(class_scope:bareun.TextSpan)
  })
_sym_db.RegisterMessage(TextSpan)

Document = _reflection.GeneratedProtocolMessageType('Document', (_message.Message,), {
  'DESCRIPTOR' : _DOCUMENT,
  '__module__' : 'bareun.lang_common_pb2'
  # @@protoc_insertion_point(class_scope:bareun.Document)
  })
_sym_db.RegisterMessage(Document)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\020ai.bareun.protosB\017LangCommonProtoP\001Z\026bareun.ai/proto/bareun'
  _ENCODINGTYPE._serialized_start=150
  _ENCODINGTYPE._serialized_end=206
  _TEXTSPAN._serialized_start=36
  _TEXTSPAN._serialized_end=101
  _DOCUMENT._serialized_start=103
  _DOCUMENT._serialized_end=148
# @@protoc_insertion_point(module_scope)
