"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2024-present BAIKAL AI Inc."""
import abc
import bareun.revision_service_pb2
import grpc

class RevisionServiceStub:
    """다양한 목적에 맞는 문장 교정 서비스
    이 서비스는 다른 과금 체계를 가지므로 다양하게 재구성한다.
    """

    def __init__(self, channel: grpc.Channel) -> None: ...
    CorrectError: grpc.UnaryUnaryMultiCallable[
        bareun.revision_service_pb2.CorrectErrorRequest,
        bareun.revision_service_pb2.CorrectErrorResponse,
    ]
    """맞춤법 교정을 수행한다."""

class RevisionServiceServicer(metaclass=abc.ABCMeta):
    """다양한 목적에 맞는 문장 교정 서비스
    이 서비스는 다른 과금 체계를 가지므로 다양하게 재구성한다.
    """

    @abc.abstractmethod
    def CorrectError(
        self,
        request: bareun.revision_service_pb2.CorrectErrorRequest,
        context: grpc.ServicerContext,
    ) -> bareun.revision_service_pb2.CorrectErrorResponse:
        """맞춤법 교정을 수행한다."""

def add_RevisionServiceServicer_to_server(servicer: RevisionServiceServicer, server: grpc.Server) -> None: ...
